exceptiontools.MissingMarkError
===============================

.. inheritance-diagram:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.MissingMarkError.MissingMarkError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
